==> v3.5.13.1.tar.gz: tdewebdev/kommander/part/kommander_part.h <==
/***************************************************************************
    begin                : Wed Jan 30 2008
    copyright            : (C) 2008, Andras Mantia <amantia@kde.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef KOMMANDERPART_H
#define KOMMANDERPART_H

#include <kparts/part.h>
#include <kparts/factory.h>

class Instance;
class TQGridLayout;

class KommanderPart : public KParts::ReadOnlyPart
{
    Q_OBJECT
  TQ_OBJECT
public:
    KommanderPart(TQWidget *parentWidget, const char *widgetName,
                  TQObject *parent, const char *name, const TQStringList &args);

    virtual ~KommanderPart();

    static KAboutData* createAboutData();

protected:
    virtual bool openFile();

protected slots:
    void slotRun();

private:
    Instance *m_instance;
    TQWidget *m_widget;
    TQGridLayout *m_layout;
};


#endif // KOMMANDERPART_H

==> r14.0.13.tar.gz: tdewebdev/kommander/part/kommander_part.h <==
/***************************************************************************
    begin                : Wed Jan 30 2008
    copyright            : (C) 2008, Andras Mantia <amantia@kde.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 
#ifndef KOMMANDERPART_H
#define KOMMANDERPART_H

#include <tdeparts/part.h>
#include <tdeparts/factory.h>

class Instance;
class TQGridLayout;

class KommanderPart : public KParts::ReadOnlyPart
{
    Q_OBJECT
  
public:
    KommanderPart(TQWidget *parentWidget, const char *widgetName,
                  TQObject *parent, const char *name, const TQStringList &args);

    virtual ~KommanderPart();

    static TDEAboutData* createAboutData();

protected:
    virtual bool openFile();

protected slots:
    void slotRun();

private:
    Instance *m_instance;
    TQWidget *m_widget;
    TQGridLayout *m_layout;
};


#endif // KOMMANDERPART_H
